@@ -4,30 +4,34 @@ pub const PS_ITEM_STATE_TOPIC: &str = "ST/";
 pub const PS_ITEM_BULK_STATE_TOPIC: &str = "STBULK/";
 pub const PS_NODE_STATE_TOPIC: &str = "NODE/ST/";
 
-#[derive(Deserialize, Serialize)]
+#[derive(Deserialize, Serialize, Copy, Clone)]
 #[serde(rename_all = "lowercase")]
 #[repr(u8)]
-pub enum NodeState {
+pub enum NodeStatus {
     Running = 1,
     Terminating = 0xef,
 }
 
 #[derive(Deserialize, Serialize)]
-pub struct PsNodeState {
-    status: NodeState,
+pub struct PsNodeStatus {
+    status: NodeStatus,
 }
 
-impl PsNodeState {
+impl PsNodeStatus {
     #[inline]
-    pub fn running() -> Self {
+    pub fn new_running() -> Self {
         Self {
-            status: NodeState::Running,
+            status: NodeStatus::Running,
         }
     }
     #[inline]
-    pub fn terminating() -> Self {
+    pub fn new_terminating() -> Self {
         Self {
-            status: NodeState::Terminating,
+            status: NodeStatus::Terminating,
         }
     }
+    #[inline]
+    pub fn status(&self) -> NodeStatus {
+        self.status
+    }
 }
