@@ -6,6 +6,7 @@ use eva_common::acl::OIDMaskList;
 use eva_common::events::{
     ANY_STATE_TOPIC, LOCAL_STATE_TOPIC, LOG_INPUT_TOPIC, REMOTE_STATE_TOPIC, SERVICE_STATUS_TOPIC,
 };
+use eva_common::payload::{pack, unpack};
 use eva_common::prelude::*;
 use eva_common::services;
 use eva_common::SLEEP_STEP;
@@ -84,7 +85,7 @@ pub fn poc() {
 pub fn svc_handle_default_rpc(method: &str, info: &services::ServiceInfo) -> RpcResult {
     match method {
         "test" => Ok(None),
-        "info" => Ok(Some(rmp_serde::to_vec_named(info)?)),
+        "info" => Ok(Some(pack(info)?)),
         "stop" => {
             svc_terminate();
             Ok(None)
@@ -130,7 +131,7 @@ pub async fn svc_wait_core(rpc: &RpcClient, timeout: Duration, wait_forever: boo
         )
         .await
         {
-            if let Ok(result) = rmp_serde::from_slice::<TR>(ev.payload()) {
+            if let Ok(result) = unpack::<TR>(ev.payload()) {
                 if result.active {
                     return Ok(());
                 }
@@ -273,7 +274,7 @@ where
 ///
 /// # Panics
 ///
-/// Will panic only if rmp_serde is broken
+/// Will panic only if payload::pack is broken
 pub async fn svc_mark_ready<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
 where
     C: AsyncClient + 'static,
@@ -283,7 +284,7 @@ where
         .await
         .publish(
             SERVICE_STATUS_TOPIC,
-            rmp_serde::to_vec_named(&services::ServiceStatusBroadcastEvent::ready())
+            pack(&services::ServiceStatusBroadcastEvent::ready())
                 .unwrap()
                 .into(),
             QoS::Processed,
@@ -299,7 +300,7 @@ where
 ///
 /// # Panics
 ///
-/// Will panic only if rmp_serde is broken
+/// Will panic only if payload::pack is broken
 pub async fn svc_mark_terminating<C: ?Sized>(client: &tokio::sync::Mutex<C>) -> EResult<()>
 where
     C: AsyncClient + 'static,
@@ -311,7 +312,7 @@ where
         .await
         .publish(
             SERVICE_STATUS_TOPIC,
-            rmp_serde::to_vec_named(&services::ServiceStatusBroadcastEvent::terminating())
+            pack(&services::ServiceStatusBroadcastEvent::terminating())
                 .unwrap()
                 .into(),
             QoS::Processed,
@@ -349,7 +350,7 @@ pub fn svc_start_signal_handlers() {
 }
 
 fn process_initial(buf: &[u8]) -> EResult<services::Initial> {
-    let initial: services::Initial = rmp_serde::from_slice(buf)?;
+    let initial: services::Initial = unpack(buf)?;
     if initial.config_version() != services::SERVICE_CONFIG_VERSION {
         return Err(Error::not_implemented(format!(
             "config version not supported: {}",
